@@ -1015,26 +1015,43 @@ def interpolant_h(t, h, deg=3, s=None):
 def interpolate_h(tin, h, tout, deg=3, s=None):
   """Interpolate input data h at samples tout.
 
-  s is the spline smooth parameter
+  INPUT
+  =====
+  tin:  input time grid
+  h:    input waveform such that h = h(tin); h can be a dicionary
+  tout: output time grid
+  deg:  degree of spline
+  s:    spline smooth parameter
 
+  Note: h can be a dictionary of modes
   """
 
-  from scipy.interpolate import splrep
-  from scipy.interpolate import splev
-  
-  if tout[0] < tin[0] or tout[-1] > tin[-1]:
-    print(">>> Warning: Requested samples are outside of interpolated domain.")
-  
-  dtype = h.dtype
-  if dtype == 'complex':
-    interp_real, interp_imag = interpolant_h(tin, h, deg=deg,s=s)
-    return splev(tout, interp_real) + 1j*splev(tout, interp_imag)
-  elif dtype == 'double':
-    interp = interpolant_h(tin, h, deg=deg,s=s)
-    return splev(tout, interp)
+  if type(h) is dict:
+
+    h_interp = {}
+    for mode, hlm in h.items():
+      hlm_inter = interpolate_h(tin, hlm, tout, deg=deg, s=s)
+      h_interp[mode] = hlm_inter
+    return h_interp
+
   else:
-    raise Exception("Function to be interpolated must be real or complex.")
-  pass
+
+    from scipy.interpolate import splrep
+    from scipy.interpolate import splev
+    
+    if tout[0] < tin[0] or tout[-1] > tin[-1]:
+      print(">>> Warning: Requested samples are outside of interpolated domain.")
+    
+    dtype = h.dtype
+    if dtype == 'complex':
+      interp_real, interp_imag = interpolant_h(tin, h, deg=deg,s=s)
+      return splev(tout, interp_real) + 1j*splev(tout, interp_imag)
+    elif dtype == 'double':
+      interp = interpolant_h(tin, h, deg=deg,s=s)
+      return splev(tout, interp)
+    else:
+      raise Exception("Function to be interpolated must be real or complex.")
+    pass
 
 
 def spline_f(tin, h, deg=3, s=None):
@@ -1615,18 +1632,29 @@ def modes_list_to_dict(mode_list, mode_array):
 
 #### convenient wrapper to sxs memory interface ###
 
-def sxs_memory(h_lm, times, verbose=False):
+def sxs_memory(h_lm, times, integration_start_time=None, mem_additional_ell=0, verbose=False):
   """  Compute memory modes using sxs module. Make sure sxs is installed as
   
     >>> conda install -c conda-forge sxs
   
   Input
   =====
-  h_lm: dictionary of oscillatory modes. For example,
+  h_lm:    dictionary of oscillatory modes. For example,
   
-            hdict_tmp[(2,2)] = np.array( [...] )
-  times: array of times defining the hdict_tmp modes
+               hdict_tmp[(2,2)] = np.array( [...] )
+
+  times:   array of times defining the hdict_tmp modes
   verbose: Output verbosity
+  mem_additional_ell: compute memory modes beyond ell_max found from h_lm
+
+     Example: if the largest ell in h_lm is ell=3, and mem_additional_ell=2
+              then compute memory modes up to ell=5.
+
+     Note: compute time quickly goes up with ell!
+
+  integration_start_time: float, optional
+        Time at which the energy flux integral should begin.  The default is None (times[0] used)
+
   
   Output
   ======
@@ -1653,8 +1681,8 @@ def sxs_memory(h_lm, times, verbose=False):
   if verbose:
     print("max ell = %i, min ell= %i"%(max_ell, min_ell))
 
-  # compute x2 more memory modes than oscillatory modes
-  max_ell = 2*max_ell
+  # compute more or less memory modes than oscillatory modes
+  max_ell = max_ell + mem_additional_ell
 
   modes = [(ell, m) for ell in range(2, max_ell+1) for m in range(-ell,ell+1)]
   sxs_modes = []
@@ -1670,8 +1698,9 @@ def sxs_memory(h_lm, times, verbose=False):
   h_test = sxs.waveforms.WaveformModes(sxs_modes.transpose(), time=times, modes_axis=1, time_axis=0, ell_min=min_ell, ell_max=max_ell)
   h_test._metadata['spin_weight'] = -2
 
-  # WARNING: hardcoded start time
-  h_with_memory = sxs.waveforms.memory.add_memory(h_test, start_time=times[0])
+  if integration_start_time is None:
+    integration_start_time = times[0]
+  h_with_memory = sxs.waveforms.memory.add_memory(h_test, integration_start_time=integration_start_time)
 
   memory_sxs = {}
   for mode in modes:
